package RandomFileMethodAllTests;
use base qw/RandomFileSimpleDirOption
            RandomFileCheckOption
			RandomFileRecursiveOption
			RandomFilePassesPathsToCheckRoutine
            RandomFileWithUnknownParameters/;

1;
